# Index of Names

## A

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- About_Dialog
  - `magneticalc.About_Dialog`
  - `magneticalc.About_Dialog.About_Dialog`
- absolute_filename - `magneticalc.Format.Format.absolute_filename`
- accepting - `magneticalc.QMessageBox2.QMessageBox2.accepting`
- actions - `magneticalc.QCheckboxConfig.QCheckboxConfig.actions`
- add - `magneticalc.QCheckboxConfig.QCheckboxConfig.add`
- add_group - `magneticalc.Config_Group.Config_Collection.add_group`
- addButtons - `magneticalc.QtWidgets2.QLayouted.QLayouted.addButtons`
- addLayout - `magneticalc.QtWidgets2.QLayouted.QLayouted.addLayout`
- addSpacing - `magneticalc.QtWidgets2.QLayouted.QLayouted.addSpacing`
- addWidget - `magneticalc.QtWidgets2.QLayouted.QLayouted.addWidget`
- alpha_metric_combobox - `magneticalc.Metric_Widget.Metric_Widget.alpha_metric_combobox`
- alpha_metric_limits_layout - `magneticalc.Metric_Widget.Metric_Widget.alpha_metric_limits_layout`
- alpha_metric_limits_widget - `magneticalc.Metric_Widget.Metric_Widget.alpha_metric_limits_widget`
- alpha_metric_max_label - `magneticalc.Metric_Widget.Metric_Widget.alpha_metric_max_label`
- alpha_metric_min_label - `magneticalc.Metric_Widget.Metric_Widget.alpha_metric_min_label`
- alpha_preset - `magneticalc.Metric.Metric.alpha_preset`
- AngleXY - `magneticalc.Metric_Presets.Metric_Presets.AngleXY`
- AngleXZ - `magneticalc.Metric_Presets.Metric_Presets.AngleXZ`
- AngleYZ - `magneticalc.Metric_Presets.Metric_Presets.AngleYZ`
- API
  - `magneticalc.API`
  - `magneticalc.API.API`
- arm - `magneticalc.Statusbar.Statusbar.arm`
- Assert_Dialog
  - `magneticalc.Assert_Dialog`
  - `magneticalc.Assert_Dialog.Assert_Dialog`

## B

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- backend_actions - `magneticalc.Options_Menu.Options_Menu.backend_actions`
- Backend_CUDA
  - `magneticalc.Backend_CUDA`
  - `magneticalc.Backend_CUDA.Backend_CUDA`
- Backend_JIT
  - `magneticalc.Backend_JIT`
  - `magneticalc.Backend_JIT.Backend_JIT`
- BACKEND_TYPE_CUDA - `magneticalc.Backend_Types.BACKEND_TYPE_CUDA`
- BACKEND_TYPE_JIT - `magneticalc.Backend_Types.BACKEND_TYPE_JIT`
- backend_type_safe - `magneticalc.Backend_Types.backend_type_safe`
- backend_type_to_name - `magneticalc.Backend_Types.backend_type_to_name`
- Backend_Types - `magneticalc.Backend_Types`
- Backend_Types_Available - `magneticalc.Backend_Types.Backend_Types_Available`
- Backend_Types_Names_Map - `magneticalc.Backend_Types.Backend_Types_Names_Map`
- background - `magneticalc.VisPyCanvas.VisPyCanvas.background`
- bgcolor - `magneticalc.VisPyCanvas.VisPyCanvas.bgcolor`
- Black - `magneticalc.VisPyCanvas.VisPyCanvas.Black`
- Blacklist - `magneticalc.Debug.Debug.Blacklist`
- boost_colors - `magneticalc.Metric.Metric.boost_colors`
- bounds
  - `magneticalc.SamplingVolume.SamplingVolume.bounds`
  - `magneticalc.Wire.Wire.bounds`
- bounds_max_spinbox - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.bounds_max_spinbox`
- bounds_min_spinbox - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.bounds_min_spinbox`
- BoundsRange - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.BoundsRange`
- buttons - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.buttons`

## C

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- calculate_field - `magneticalc.Model.Model.calculate_field`
- calculate_metric - `magneticalc.Model.Model.calculate_metric`
- calculate_parameters - `magneticalc.Model.Model.calculate_parameters`
- calculate_sampling_volume - `magneticalc.Model.Model.calculate_sampling_volume`
- calculate_wire - `magneticalc.Model.Model.calculate_wire`
- calculation_exited - `magneticalc.GUI.GUI.calculation_exited`
- calculation_start_time - `magneticalc.GUI.GUI.calculation_start_time`
- calculation_status - `magneticalc.GUI.GUI.calculation_status`
- calculation_thread - `magneticalc.GUI.GUI.calculation_thread`
- CalculationThread
  - `magneticalc.CalculationThread`
  - `magneticalc.CalculationThread.CalculationThread`
- cancel - `magneticalc.Statusbar.Statusbar.cancel`
- changed
  - `magneticalc.Constraint_Editor.Constraint_Editor.changed`
  - `magneticalc.QCheckboxConfig.QCheckboxConfig.changed`
- changed.setter - `magneticalc.Constraint_Editor.Constraint_Editor.changed.setter`
- check_for_updates - `magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.check_for_updates`
- checkbox_config - `magneticalc.View_Menu.View_Menu.checkbox_config`
- checkboxes - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.checkboxes`
- CheckForUpdates_Dialog
  - `magneticalc.CheckForUpdates_Dialog`
  - `magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog`
- choice - `magneticalc.QMessageBox2.QMessageBox2.choice`
- cleanup
  - `magneticalc.Config.Config.cleanup`
  - `magneticalc.GUI.GUI.cleanup`
- clear_padding - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.clear_padding`
- clear_rotational_symmetry - `magneticalc.Wire_Widget.Wire_Widget.clear_rotational_symmetry`
- clear_stretch - `magneticalc.Wire_Widget.Wire_Widget.clear_stretch`
- close - `magneticalc.Project.Project.close`
- close_loop_checkbox - `magneticalc.Wire_Widget.Wire_Widget.close_loop_checkbox`
- close_project - `magneticalc.File_Menu.File_Menu.close_project`
- closeEvent - `magneticalc.GUI.GUI.closeEvent`
- color_map_cyclic - `magneticalc.Metric.color_map_cyclic`
- color_map_divergent - `magneticalc.Metric.color_map_divergent`
- color_metric_combobox - `magneticalc.Metric_Widget.Metric_Widget.color_metric_combobox`
- color_metric_limits_layout - `magneticalc.Metric_Widget.Metric_Widget.color_metric_limits_layout`
- color_metric_limits_widget - `magneticalc.Metric_Widget.Metric_Widget.color_metric_limits_widget`
- color_metric_max_label - `magneticalc.Metric_Widget.Metric_Widget.color_metric_max_label`
- color_metric_min_label - `magneticalc.Metric_Widget.Metric_Widget.color_metric_min_label`
- color_preset - `magneticalc.Metric.Metric.color_preset`
- colors - `magneticalc.Metric.Metric.colors`
- columnCount - `magneticalc.QTableView2.TableModel.columnCount`
- comparison_name_to_type - `magneticalc.Comparison_Types.comparison_name_to_type`
- COMPARISON_TYPE_IN_RANGE - `magneticalc.Comparison_Types.COMPARISON_TYPE_IN_RANGE`
- COMPARISON_TYPE_NOT_IN_RANGE - `magneticalc.Comparison_Types.COMPARISON_TYPE_NOT_IN_RANGE`
- comparison_type_safe - `magneticalc.Comparison_Types.comparison_type_safe`
- comparison_type_to_name - `magneticalc.Comparison_Types.comparison_type_to_name`
- Comparison_Types - `magneticalc.Comparison_Types`
- Comparison_Types_Names_Map - `magneticalc.Comparison_Types.Comparison_Types_Names_Map`
- Comparison_Types_Supported - `magneticalc.Constraint.Constraint.Comparison_Types_Supported`
- CompensatedDoubleSquareLoop_Centered - `magneticalc.Wire_Presets.Wire_Presets.CompensatedDoubleSquareLoop_Centered`
- CompensatedDoubleSquareLoop_Offset - `magneticalc.Wire_Presets.Wire_Presets.CompensatedDoubleSquareLoop_Offset`
- CompensatedSolenoidCircularLoops4 - `magneticalc.Wire_Presets.Wire_Presets.CompensatedSolenoidCircularLoops4`
- CompensatedSolenoidCircularLoops8 - `magneticalc.Wire_Presets.Wire_Presets.CompensatedSolenoidCircularLoops8`
- condition - `magneticalc.ConditionalDecorator.ConditionalDecorator.condition`
- ConditionalDecorator
  - `magneticalc.ConditionalDecorator`
  - `magneticalc.ConditionalDecorator.ConditionalDecorator`
- Config
  - `magneticalc.Config`
  - `magneticalc.Config.Config`
- Config_Collection - `magneticalc.Config_Group.Config_Collection`
- Config_Group - `magneticalc.Config_Group`
- Constants
  - `magneticalc.Constants`
  - `magneticalc.Constants.Constants`
- Constraint
  - `magneticalc.Constraint`
  - `magneticalc.Constraint.Constraint`
- Constraint_Editor
  - `magneticalc.Constraint_Editor`
  - `magneticalc.Constraint_Editor.Constraint_Editor`
- constraint_editor - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.constraint_editor`
- Constraint_Options - `magneticalc.Constraint_Editor.Constraint_Editor.Constraint_Options`
- Constraint_Types - `magneticalc.Constraint_Editor.Constraint_Editor.Constraint_Types`
- Cool_Gradient_CSS - `magneticalc.Metric_Widget.Metric_Widget.Cool_Gradient_CSS`
- CoordinatePrecision - `magneticalc.Format.Format.CoordinatePrecision`
- Copyright - `magneticalc.Version.Version.Copyright`
- create_field_labels - `magneticalc.VisPyCanvas.VisPyCanvas.create_field_labels`

## D

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- DarkColor - `magneticalc.Theme.Theme.DarkColor`
- data - `magneticalc.QTableView2.TableModel.data`
- dc - `magneticalc.Wire.Wire.dc`
- dc_spinbox - `magneticalc.Wire_Widget.Wire_Widget.dc_spinbox`
- DcMax - `magneticalc.Wire_Widget.Wire_Widget.DcMax`
- DcMin - `magneticalc.Wire_Widget.Wire_Widget.DcMin`
- DcPrecision - `magneticalc.Wire_Widget.Wire_Widget.DcPrecision`
- DcStep - `magneticalc.Wire_Widget.Wire_Widget.DcStep`
- Debug
  - `magneticalc.Debug`
  - `magneticalc.Debug.Debug`
- DebugAccess - `magneticalc.Config.Config.DebugAccess`
- DebugInvalidate - `magneticalc.Model.Model.DebugInvalidate`
- DebugLabels - `magneticalc.QtWidgets2.QLabel2.QLabel2.DebugLabels`
- DebugPerspective - `magneticalc.VisPyCanvas.VisPyCanvas.DebugPerspective`
- DebugValidity - `magneticalc.ModelAccess.ModelAccess.DebugValidity`
- DebugVisuals - `magneticalc.VisPyCanvas.VisPyCanvas.DebugVisuals`
- decorating_args - `magneticalc.ConditionalDecorator.ConditionalDecorator.decorating_args`
- decorating_func - `magneticalc.ConditionalDecorator.ConditionalDecorator.decorating_func`
- DefaultFontFace - `magneticalc.Theme.Theme.DefaultFontFace`
- DefaultFontSize - `magneticalc.VisPyCanvas.VisPyCanvas.DefaultFontSize`
- DefaultRotationalSymmetry - `magneticalc.Wire_Widget.DefaultRotationalSymmetry`
- DefaultStretch - `magneticalc.Wire_Widget.DefaultStretch`
- del_group - `magneticalc.Config_Group.Config_Collection.del_group`
- delete_field_labels - `magneticalc.VisPyCanvas.VisPyCanvas.delete_field_labels`
- DialogTextColor - `magneticalc.Theme.Theme.DialogTextColor`
- dictionary
  - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.dictionary`
  - `magneticalc.QtWidgets2.QButtons.QButtons.dictionary`
- dimension - `magneticalc.SamplingVolume.SamplingVolume.dimension`
- disable_field_labels - `magneticalc.Display_Widget.Display_Widget.disable_field_labels`
- disarm - `magneticalc.Statusbar.Statusbar.disarm`
- disconnect_signals - `magneticalc.CalculationThread.CalculationThread.disconnect_signals`
- display_field_magnitude_labels_checkbox - `magneticalc.Display_Widget.Display_Widget.display_field_magnitude_labels_checkbox`
- Display_Widget
  - `magneticalc.Display_Widget`
  - `magneticalc.Display_Widget.Display_Widget`
- display_widget - `magneticalc.SidebarRight.SidebarRight.display_widget`
- distance_limit_spinbox - `magneticalc.Field_Widget.Field_Widget.distance_limit_spinbox`
- DistanceLimitMax - `magneticalc.Field_Widget.Field_Widget.DistanceLimitMax`
- DistanceLimitMin - `magneticalc.Field_Widget.Field_Widget.DistanceLimitMin`
- DistanceLimitPrecision - `magneticalc.Field_Widget.Field_Widget.DistanceLimitPrecision`
- DistanceLimitStep - `magneticalc.Field_Widget.Field_Widget.DistanceLimitStep`
- Divergence - `magneticalc.Metric_Presets.Metric_Presets.Divergence`
- DonationURL - `magneticalc.About_Dialog.About_Dialog.DonationURL`

## E

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- elements - `magneticalc.Wire.Wire.elements`
- EnableBlacklist - `magneticalc.Debug.Debug.EnableBlacklist`
- EnableInit - `magneticalc.Debug.Debug.EnableInit`
- EnableRefresh - `magneticalc.Debug.Debug.EnableRefresh`
- energy - `magneticalc.Parameters.Parameters.energy`
- energy_units_label - `magneticalc.Parameters_Widget.Parameters_Widget.energy_units_label`
- energy_value_label - `magneticalc.Parameters_Widget.Parameters_Widget.energy_value_label`
- evaluate - `magneticalc.Constraint.Constraint.evaluate`
- ExcessiveFieldLabelsThreshold - `magneticalc.Display_Widget.Display_Widget.ExcessiveFieldLabelsThreshold`
- exiting - `magneticalc.GUI.GUI.exiting`
- export - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.export`
- export_hdf5 - `magneticalc.API.API.export_hdf5`
- export_image - `magneticalc.File_Menu.File_Menu.export_image`
- Export_Names_Available_Map - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.Export_Names_Available_Map`
- export_wire - `magneticalc.API.API.export_wire`
- export_wire_action - `magneticalc.Wire_Menu.Wire_Menu.export_wire_action`
- ExportContainer_Dialog
  - `magneticalc.ExportContainer_Dialog`
  - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog`
- extent - `magneticalc.SamplingVolume.SamplingVolume.extent`

## F

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- FailureColor - `magneticalc.Theme.Theme.FailureColor`
- Field
  - `magneticalc.Field`
  - `magneticalc.Field.Field`
- field - `magneticalc.Model.Model.field`
- field_arrow_head_scale_slider - `magneticalc.Display_Widget.Display_Widget.field_arrow_head_scale_slider`
- field_arrow_line_scale_slider - `magneticalc.Display_Widget.Display_Widget.field_arrow_line_scale_slider`
- field_boost_slider - `magneticalc.Display_Widget.Display_Widget.field_boost_slider`
- field_label_resolution_combobox - `magneticalc.Display_Widget.Display_Widget.field_label_resolution_combobox`
- field_label_resolution_combobox_connection - `magneticalc.Display_Widget.Display_Widget.field_label_resolution_combobox_connection`
- field_name_to_type - `magneticalc.Field_Types.field_name_to_type`
- field_point_scale_slider - `magneticalc.Display_Widget.Display_Widget.field_point_scale_slider`
- FIELD_TYPE_A - `magneticalc.Field_Types.FIELD_TYPE_A`
- FIELD_TYPE_B - `magneticalc.Field_Types.FIELD_TYPE_B`
- field_type_checkboxes - `magneticalc.Field_Widget.Field_Widget.field_type_checkboxes`
- field_type_group - `magneticalc.Field_Widget.Field_Widget.field_type_group`
- field_type_safe - `magneticalc.Field_Types.field_type_safe`
- field_type_select - `magneticalc.Model.Model.field_type_select`
- field_type_select.setter - `magneticalc.Model.Model.field_type_select.setter`
- Field_Types - `magneticalc.Field_Types`
- Field_Types_Abbreviations_Map - `magneticalc.Field_Types.Field_Types_Abbreviations_Map`
- Field_Types_Names_Map - `magneticalc.Field_Types.Field_Types_Names_Map`
- Field_Widget
  - `magneticalc.Field_Widget`
  - `magneticalc.Field_Widget.Field_Widget`
- field_widget - `magneticalc.SidebarRight.SidebarRight.field_widget`
- FieldArrowHeadScaleMax - `magneticalc.Display_Widget.Display_Widget.FieldArrowHeadScaleMax`
- FieldArrowHeadScaleMin - `magneticalc.Display_Widget.Display_Widget.FieldArrowHeadScaleMin`
- FieldArrowHeadScaleStep - `magneticalc.Display_Widget.Display_Widget.FieldArrowHeadScaleStep`
- FieldArrowHeadSize - `magneticalc.VisPyCanvas.VisPyCanvas.FieldArrowHeadSize`
- FieldArrowLineScaleMax - `magneticalc.Display_Widget.Display_Widget.FieldArrowLineScaleMax`
- FieldArrowLineScaleMin - `magneticalc.Display_Widget.Display_Widget.FieldArrowLineScaleMin`
- FieldArrowLineScaleStep - `magneticalc.Display_Widget.Display_Widget.FieldArrowLineScaleStep`
- FieldBoostMax - `magneticalc.Display_Widget.Display_Widget.FieldBoostMax`
- FieldBoostMin - `magneticalc.Display_Widget.Display_Widget.FieldBoostMin`
- FieldBoostStep - `magneticalc.Display_Widget.Display_Widget.FieldBoostStep`
- FieldPointScaleMax - `magneticalc.Display_Widget.Display_Widget.FieldPointScaleMax`
- FieldPointScaleMin - `magneticalc.Display_Widget.Display_Widget.FieldPointScaleMin`
- FieldPointScaleStep - `magneticalc.Display_Widget.Display_Widget.FieldPointScaleStep`
- FieldPointSize - `magneticalc.VisPyCanvas.VisPyCanvas.FieldPointSize`
- File_Menu
  - `magneticalc.File_Menu`
  - `magneticalc.File_Menu.File_Menu`
- file_menu - `magneticalc.Menu.Menu.file_menu`
- filename
  - `magneticalc.Config.Config.filename`
  - `magneticalc.QtWidgets2.QSaveAction.QSaveAction.filename`
- filename_uri - `magneticalc.Format.Format.filename_uri`
- first_without_suffix - `magneticalc.Config_Group.Config_Collection.first_without_suffix`
- fit_to_contents - `magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2.fit_to_contents`
- flags - `magneticalc.QTableView2.TableModel.flags`
- float_to_str - `magneticalc.Format.Format.float_to_str`
- FloatPrecision - `magneticalc.Format.Format.FloatPrecision`
- focusInEvent - `magneticalc.QTableView2.QTableView2.focusInEvent`
- focusOutEvent - `magneticalc.QTableView2.QTableView2.focusOutEvent`
- font_manager - `magneticalc.VisPyCanvas.VisPyCanvas.font_manager`
- foreground - `magneticalc.VisPyCanvas.VisPyCanvas.foreground`
- Format
  - `magneticalc.Format`
  - `magneticalc.Format.Format`

## G

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- get_a_field - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_a_field`
- get_a_field_list - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_a_field_list`
- get_all_groups - `magneticalc.Config_Group.Config_Collection.get_all_groups`
- get_arrows - `magneticalc.Field.Field.get_arrows`
- get_axes - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_axes`
- get_axes_list - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_axes_list`
- get_b_field - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_b_field`
- get_b_field_list - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_b_field_list`
- get_bool - `magneticalc.Config.Config.get_bool`
- get_by_id
  - `magneticalc.Metric_Presets.Metric_Presets.get_by_id`
  - `magneticalc.Perspective_Presets.Perspective_Presets.get_by_id`
  - `magneticalc.Wire_Presets.Wire_Presets.get_by_id`
- get_constraints - `magneticalc.Constraint_Editor.Constraint_Editor.get_constraints`
- get_count - `magneticalc.Config_Group.Config_Collection.get_count`
- get_cuda_available - `magneticalc.Backend_Types.get_cuda_available`
- get_current - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_current`
- get_default - `magneticalc.Project.Project.get_default`
- get_dimension - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_dimension`
- get_field - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_field`
- get_float - `magneticalc.Config.Config.get_float`
- get_generic - `magneticalc.Config.Config.get_generic`
- get_group - `magneticalc.Config_Group.Config_Collection.get_group`
- get_int - `magneticalc.Config.Config.get_int`
- get_jit_enabled - `magneticalc.Backend_Types.get_jit_enabled`
- get_phase_jumping_toroidal_loop - `magneticalc.Wire_Presets.Wire_Presets.get_phase_jumping_toroidal_loop`
- get_point - `magneticalc.Config.Config.get_point`
- get_points - `magneticalc.Config.Config.get_points`
- get_result
  - `magneticalc.Backend_CUDA.Backend_CUDA.get_result`
  - `magneticalc.Backend_JIT.Backend_JIT.get_result`
- get_selected_row - `magneticalc.QTableView2.QTableView2.get_selected_row`
- get_str - `magneticalc.Config.Config.get_str`
- get_units - `magneticalc.Field.Field.get_units`
- get_valid_field - `magneticalc.Model.Model.get_valid_field`
- get_value - `magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.get_value`
- get_wire - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_wire`
- get_wire_list - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.get_wire_list`
- GUI
  - `magneticalc.GUI`
  - `magneticalc.GUI.GUI`
- gui
  - `magneticalc.CalculationThread.CalculationThread.gui`
  - `magneticalc.Config_Group.Config_Collection.gui`
  - `magneticalc.Constraint_Editor.Constraint_Editor.gui`
  - `magneticalc.Display_Widget.Display_Widget.gui`
  - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.gui`
  - `magneticalc.Field_Widget.Field_Widget.gui`
  - `magneticalc.File_Menu.File_Menu.gui`
  - `magneticalc.Help_Menu.Help_Menu.gui`
  - `magneticalc.Menu.Menu.gui`
  - `magneticalc.Metric_Widget.Metric_Widget.gui`
  - `magneticalc.Model.Model.gui`
  - `magneticalc.ModelAccess.ModelAccess.gui`
  - `magneticalc.Options_Menu.Options_Menu.gui`
  - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.gui`
  - `magneticalc.Parameters_Widget.Parameters_Widget.gui`
  - `magneticalc.Perspective_Widget.Perspective_Widget.gui`
  - `magneticalc.Project.Project.gui`
  - `magneticalc.QCheckboxConfig.QCheckboxConfig.gui`
  - `magneticalc.QTableView2.QTableView2.gui`
  - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.gui`
  - `magneticalc.SidebarLeft.SidebarLeft.gui`
  - `magneticalc.SidebarRight.SidebarRight.gui`
  - `magneticalc.Statusbar.Statusbar.gui`
  - `magneticalc.View_Menu.View_Menu.gui`
  - `magneticalc.VisPyCanvas.VisPyCanvas.gui`
  - `magneticalc.Wire_Menu.Wire_Menu.gui`
  - `magneticalc.Wire_Widget.Wire_Widget.gui`

## H

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- headerData - `magneticalc.QTableView2.TableModel.headerData`
- Help_Menu
  - `magneticalc.Help_Menu`
  - `magneticalc.Help_Menu.Help_Menu`
- help_menu - `magneticalc.Menu.Menu.help_menu`
- HorizontalSpacing - `magneticalc.QtWidgets2.QIconLabel.QIconLabel.HorizontalSpacing`
- HSV_Gradient_CSS - `magneticalc.Metric_Widget.Metric_Widget.HSV_Gradient_CSS`
- HTML
  - `magneticalc.About_Dialog.About_Dialog.HTML`
  - `magneticalc.Constraint_Editor.Constraint_Editor.HTML`
  - `magneticalc.Usage_Dialog.Usage_Dialog.HTML`

## I

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- import_hdf5 - `magneticalc.API.API.import_hdf5`
- import_wire - `magneticalc.API.API.import_wire`
- import_wire_action - `magneticalc.Wire_Menu.Wire_Menu.import_wire_action`
- initializing
  - `magneticalc.GUI.GUI.initializing`
  - `magneticalc.VisPyCanvas.VisPyCanvas.initializing`
- install_layout - `magneticalc.QtWidgets2.QLayouted.QLayouted.install_layout`
- interrupt_calculation - `magneticalc.GUI.GUI.interrupt_calculation`
- invalidate
  - `magneticalc.Model.Model.invalidate`
  - `magneticalc.Statusbar.Statusbar.invalidate`
- invalidate_statusbar - `magneticalc.GUI.GUI.invalidate_statusbar`
- is_widget - `magneticalc.QTableView2.TableModel.is_widget`
- Isometric - `magneticalc.Perspective_Presets.Perspective_Presets.Isometric`

## K

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- keyPressEvent - `magneticalc.GUI.GUI.keyPressEvent`

## L

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- labeled_indices - `magneticalc.SamplingVolume.SamplingVolume.labeled_indices`
- labels_count - `magneticalc.SamplingVolume.SamplingVolume.labels_count`
- layout - `magneticalc.Statusbar.Statusbar.layout`
- length - `magneticalc.Wire.Wire.length`
- LengthScale - `magneticalc.Metric.Metric.LengthScale`
- License - `magneticalc.Version.Version.License`
- limits - `magneticalc.Metric.Metric.limits`
- List
  - `magneticalc.Metric_Presets.Metric_Presets.List`
  - `magneticalc.Perspective_Presets.Perspective_Presets.List`
  - `magneticalc.Wire_Presets.Wire_Presets.List`
- LiteColor - `magneticalc.Theme.Theme.LiteColor`
- load - `magneticalc.Config.Config.load`
- load_file - `magneticalc.Config.Config.load_file`
- load_perspective - `magneticalc.VisPyCanvas.VisPyCanvas.load_perspective`
- LogDivergence - `magneticalc.Metric_Presets.Metric_Presets.LogDivergence`
- LogMagnitude - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitude`
- LogMagnitudeX - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeX`
- LogMagnitudeXY - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeXY`
- LogMagnitudeXZ - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeXZ`
- LogMagnitudeY - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeY`
- LogMagnitudeYZ - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeYZ`
- LogMagnitudeZ - `magneticalc.Metric_Presets.Metric_Presets.LogMagnitudeZ`
- LogNormMin - `magneticalc.Metric.Metric.LogNormMin`

## M

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- magnetic_dipole_moment - `magneticalc.Parameters.Parameters.magnetic_dipole_moment`
- magnetic_dipole_moment_units_label - `magneticalc.Parameters_Widget.Parameters_Widget.magnetic_dipole_moment_units_label`
- magnetic_dipole_moment_value_label - `magneticalc.Parameters_Widget.Parameters_Widget.magnetic_dipole_moment_value_label`
- magneticalc - `magneticalc`
- MagnetiCalc_Data
  - `magneticalc.MagnetiCalc_Data`
  - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data`
- Magnitude - `magneticalc.Metric_Presets.Metric_Presets.Magnitude`
- MagnitudeLimit - `magneticalc.VisPyCanvas.VisPyCanvas.MagnitudeLimit`
- MagnitudePrecision - `magneticalc.VisPyCanvas.VisPyCanvas.MagnitudePrecision`
- MagnitudeX - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeX`
- MagnitudeXY - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeXY`
- MagnitudeXZ - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeXZ`
- MagnitudeY - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeY`
- MagnitudeYZ - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeYZ`
- MagnitudeZ - `magneticalc.Metric_Presets.Metric_Presets.MagnitudeZ`
- main - `magneticalc.__main__.main`
- MainColor - `magneticalc.Theme.Theme.MainColor`
- MaximumWidth
  - `magneticalc.SidebarLeft.SidebarLeft.MaximumWidth`
  - `magneticalc.SidebarRight.SidebarRight.MaximumWidth`
- Menu
  - `magneticalc.Menu`
  - `magneticalc.Menu.Menu`
- menu - `magneticalc.GUI.GUI.menu`
- Metric
  - `magneticalc.Metric`
  - `magneticalc.Metric.Metric`
- metric - `magneticalc.Model.Model.metric`
- metric_divergence - `magneticalc.Metric.metric_divergence`
- metric_norm - `magneticalc.Metric.metric_norm`
- Metric_Presets
  - `magneticalc.Metric_Presets`
  - `magneticalc.Metric_Presets.Metric_Presets`
- Metric_Widget
  - `magneticalc.Metric_Widget`
  - `magneticalc.Metric_Widget.Metric_Widget`
- metric_widget - `magneticalc.SidebarRight.SidebarRight.metric_widget`
- MinimumWindowSize - `magneticalc.GUI.GUI.MinimumWindowSize`
- Model
  - `magneticalc.Model`
  - `magneticalc.Model.Model`
- model - `magneticalc.GUI.GUI.model`
- ModelAccess
  - `magneticalc.ModelAccess`
  - `magneticalc.ModelAccess.ModelAccess`
- mu_0 - `magneticalc.Constants.Constants.mu_0`

## N

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- NegDivergence - `magneticalc.Metric_Presets.Metric_Presets.NegDivergence`
- NegLogDivergence - `magneticalc.Metric_Presets.Metric_Presets.NegLogDivergence`
- neighbor_indices - `magneticalc.SamplingVolume.SamplingVolume.neighbor_indices`
- new_project - `magneticalc.File_Menu.File_Menu.new_project`
- norm_name_to_type - `magneticalc.Norm_Types.norm_name_to_type`
- NORM_TYPE_ANGLE_XY - `magneticalc.Norm_Types.NORM_TYPE_ANGLE_XY`
- NORM_TYPE_ANGLE_XZ - `magneticalc.Norm_Types.NORM_TYPE_ANGLE_XZ`
- NORM_TYPE_ANGLE_YZ - `magneticalc.Norm_Types.NORM_TYPE_ANGLE_YZ`
- NORM_TYPE_DIVERGENCE - `magneticalc.Norm_Types.NORM_TYPE_DIVERGENCE`
- NORM_TYPE_RADIUS - `magneticalc.Norm_Types.NORM_TYPE_RADIUS`
- NORM_TYPE_RADIUS_X - `magneticalc.Norm_Types.NORM_TYPE_RADIUS_X`
- NORM_TYPE_RADIUS_XY - `magneticalc.Norm_Types.NORM_TYPE_RADIUS_XY`
- NORM_TYPE_RADIUS_XZ - `magneticalc.Norm_Types.NORM_TYPE_RADIUS_XZ`
- NORM_TYPE_RADIUS_Y - `magneticalc.Norm_Types.NORM_TYPE_RADIUS_Y`
- NORM_TYPE_RADIUS_YZ - `magneticalc.Norm_Types.NORM_TYPE_RADIUS_YZ`
- NORM_TYPE_RADIUS_Z - `magneticalc.Norm_Types.NORM_TYPE_RADIUS_Z`
- norm_type_safe - `magneticalc.Norm_Types.norm_type_safe`
- norm_type_to_name - `magneticalc.Norm_Types.norm_type_to_name`
- NORM_TYPE_X - `magneticalc.Norm_Types.NORM_TYPE_X`
- NORM_TYPE_Y - `magneticalc.Norm_Types.NORM_TYPE_Y`
- NORM_TYPE_Z - `magneticalc.Norm_Types.NORM_TYPE_Z`
- Norm_Types - `magneticalc.Norm_Types`
- Norm_Types_Names_Map - `magneticalc.Norm_Types.Norm_Types_Names_Map`
- Norm_Types_Supported - `magneticalc.Constraint.Constraint.Norm_Types_Supported`
- Norm_Types_Supported_Degrees - `magneticalc.Constraint.Constraint.Norm_Types_Supported_Degrees`

## O

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- on_backend_changed - `magneticalc.Options_Menu.Options_Menu.on_backend_changed`
- on_calculation_exited - `magneticalc.GUI.GUI.on_calculation_exited`
- on_changed
  - `magneticalc.Config.Config.on_changed`
  - `magneticalc.Project.Project.on_changed`
- on_combobox_cell_edited - `magneticalc.QTableView2.QTableView2.on_combobox_cell_edited`
- on_data_changed - `magneticalc.QTableView2.QTableView2.on_data_changed`
- on_field_invalid - `magneticalc.Model.Model.on_field_invalid`
- on_field_type_changed - `magneticalc.Field_Widget.Field_Widget.on_field_type_changed`
- on_field_valid - `magneticalc.Model.Model.on_field_valid`
- on_metric_invalid - `magneticalc.Model.Model.on_metric_invalid`
- on_metric_valid - `magneticalc.Model.Model.on_metric_valid`
- on_parameters_invalid - `magneticalc.Model.Model.on_parameters_invalid`
- on_parameters_valid - `magneticalc.Model.Model.on_parameters_valid`
- on_perspective_changed - `magneticalc.VisPyCanvas.VisPyCanvas.on_perspective_changed`
- on_row_deleted - `magneticalc.QTableView2.QTableView2.on_row_deleted`
- on_sampling_volume_invalid - `magneticalc.Model.Model.on_sampling_volume_invalid`
- on_sampling_volume_valid - `magneticalc.Model.Model.on_sampling_volume_valid`
- on_selection_changed - `magneticalc.QTableView2.QTableView2.on_selection_changed`
- on_show_gauss_changed - `magneticalc.View_Menu.View_Menu.on_show_gauss_changed`
- on_table_cell_edited
  - `magneticalc.Constraint_Editor.Constraint_Editor.on_table_cell_edited`
  - `magneticalc.Wire_Widget.Wire_Widget.on_table_cell_edited`
- on_table_row_added
  - `magneticalc.Constraint_Editor.Constraint_Editor.on_table_row_added`
  - `magneticalc.Wire_Widget.Wire_Widget.on_table_row_added`
- on_table_row_deleted
  - `magneticalc.Constraint_Editor.Constraint_Editor.on_table_row_deleted`
  - `magneticalc.Wire_Widget.Wire_Widget.on_table_row_deleted`
- on_wire_invalid - `magneticalc.Model.Model.on_wire_invalid`
- on_wire_valid - `magneticalc.Model.Model.on_wire_valid`
- open - `magneticalc.Project.Project.open`
- open_constraint_editor - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.open_constraint_editor`
- open_default - `magneticalc.Project.Project.open_default`
- open_project - `magneticalc.File_Menu.File_Menu.open_project`
- options_backend_group - `magneticalc.Options_Menu.Options_Menu.options_backend_group`
- Options_Menu
  - `magneticalc.Options_Menu`
  - `magneticalc.Options_Menu.Options_Menu`
- options_menu - `magneticalc.Menu.Menu.options_menu`
- override_padding - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.override_padding`
- OverridePadding_Dialog
  - `magneticalc.OverridePadding_Dialog`
  - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog`

## P

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- padding_spinbox - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.padding_spinbox`
- padding_widget - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.padding_widget`
- PaddingMax - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.PaddingMax`
- PaddingMin - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.PaddingMin`
- Parameters
  - `magneticalc.Parameters`
  - `magneticalc.Parameters.Parameters`
- parameters - `magneticalc.Model.Model.parameters`
- Parameters_Widget
  - `magneticalc.Parameters_Widget`
  - `magneticalc.Parameters_Widget.Parameters_Widget`
- parameters_widget - `magneticalc.SidebarRight.SidebarRight.parameters_widget`
- parse_contents - `magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.parse_contents`
- permeabilities - `magneticalc.SamplingVolume.SamplingVolume.permeabilities`
- permeability - `magneticalc.Constraint.Constraint.permeability`
- Perspective_Presets
  - `magneticalc.Perspective_Presets`
  - `magneticalc.Perspective_Presets.Perspective_Presets`
- Perspective_Widget
  - `magneticalc.Perspective_Widget`
  - `magneticalc.Perspective_Widget.Perspective_Widget`
- perspective_widget - `magneticalc.SidebarRight.SidebarRight.perspective_widget`
- PhaseJumpingToroidalLoop16 - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop16`
- PhaseJumpingToroidalLoop32HiRes - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32HiRes`
- PhaseJumpingToroidalLoop32HiResFlat - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32HiResFlat`
- PhaseJumpingToroidalLoop32LoRes - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32LoRes`
- PhaseJumpingToroidalLoop32LoResFlat - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop32LoResFlat`
- PhaseJumpingToroidalLoop8 - `magneticalc.Wire_Presets.Wire_Presets.PhaseJumpingToroidalLoop8`
- PlaneXY - `magneticalc.Perspective_Presets.Perspective_Presets.PlaneXY`
- PlaneXZ - `magneticalc.Perspective_Presets.Perspective_Presets.PlaneXZ`
- PlaneYZ - `magneticalc.Perspective_Presets.Perspective_Presets.PlaneYZ`
- point_to_str - `magneticalc.Format.Format.point_to_str`
- points - `magneticalc.SamplingVolume.SamplingVolume.points`
- points_base - `magneticalc.Wire.Wire.points_base`
- points_count - `magneticalc.SamplingVolume.SamplingVolume.points_count`
- points_sliced - `magneticalc.Wire.Wire.points_sliced`
- points_to_str - `magneticalc.Format.Format.points_to_str`
- points_transformed - `magneticalc.Wire.Wire.points_transformed`
- PosDivergence - `magneticalc.Metric_Presets.Metric_Presets.PosDivergence`
- PosLogDivergence - `magneticalc.Metric_Presets.Metric_Presets.PosLogDivergence`
- prefix - `magneticalc.Config_Group.Config_Collection.prefix`
- prevent_excessive_field_labels - `magneticalc.Display_Widget.Display_Widget.prevent_excessive_field_labels`
- Project
  - `magneticalc.Project`
  - `magneticalc.Project.Project`
- project - `magneticalc.GUI.GUI.project`

## Q

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- QButtons
  - `magneticalc.QtWidgets2.QButtons`
  - `magneticalc.QtWidgets2.QButtons.QButtons`
- QCheckboxConfig
  - `magneticalc.QCheckboxConfig`
  - `magneticalc.QCheckboxConfig.QCheckboxConfig`
- QDialog2
  - `magneticalc.QtWidgets2.QDialog2`
  - `magneticalc.QtWidgets2.QDialog2.QDialog2`
- QDoubleSpinBox2
  - `magneticalc.QtWidgets2.QDoubleSpinBox2`
  - `magneticalc.QtWidgets2.QDoubleSpinBox2.QDoubleSpinBox2`
- QGroupBox2
  - `magneticalc.QtWidgets2.QGroupBox2`
  - `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2`
- QHBoxLayout2
  - `magneticalc.QtWidgets2.QHBoxLayout2`
  - `magneticalc.QtWidgets2.QHBoxLayout2.QHBoxLayout2`
- QHLine
  - `magneticalc.QtWidgets2.QHLine`
  - `magneticalc.QtWidgets2.QHLine.QHLine`
- QIconLabel
  - `magneticalc.QtWidgets2.QIconLabel`
  - `magneticalc.QtWidgets2.QIconLabel.QIconLabel`
- QLabel2
  - `magneticalc.QtWidgets2.QLabel2`
  - `magneticalc.QtWidgets2.QLabel2.QLabel2`
- QLayouted
  - `magneticalc.QtWidgets2.QLayouted`
  - `magneticalc.QtWidgets2.QLayouted.QLayouted`
- QMessageBox2
  - `magneticalc.QMessageBox2`
  - `magneticalc.QMessageBox2.QMessageBox2`
- QPushButton2
  - `magneticalc.QtWidgets2.QPushButton2`
  - `magneticalc.QtWidgets2.QPushButton2.QPushButton2`
- QSaveAction
  - `magneticalc.QtWidgets2.QSaveAction`
  - `magneticalc.QtWidgets2.QSaveAction.QSaveAction`
- QSliderFloat
  - `magneticalc.QtWidgets2.QSliderFloat`
  - `magneticalc.QtWidgets2.QSliderFloat.QSliderFloat`
- QSpinBox2
  - `magneticalc.QtWidgets2.QSpinBox2`
  - `magneticalc.QtWidgets2.QSpinBox2.QSpinBox2`
- QTableView2
  - `magneticalc.QTableView2`
  - `magneticalc.QTableView2.QTableView2`
- QTextBrowser2
  - `magneticalc.QtWidgets2.QTextBrowser2`
  - `magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2`
- QtWidgets2 - `magneticalc.QtWidgets2`
- QuestionColor - `magneticalc.Theme.Theme.QuestionColor`

## R

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- re_wrapper - `magneticalc.GUI.GUI.re_wrapper`
- readjust - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.readjust`
- recalculate
  - `magneticalc.Field.Field.recalculate`
  - `magneticalc.GUI.GUI.recalculate`
  - `magneticalc.Metric.Metric.recalculate`
  - `magneticalc.Parameters.Parameters.recalculate`
  - `magneticalc.SamplingVolume.SamplingVolume.recalculate`
  - `magneticalc.Wire.Wire.recalculate`
- redraw
  - `magneticalc.GUI.GUI.redraw`
  - `magneticalc.VisPyCanvas.VisPyCanvas.redraw`
- redraw_field_arrows - `magneticalc.VisPyCanvas.VisPyCanvas.redraw_field_arrows`
- redraw_field_labels - `magneticalc.VisPyCanvas.VisPyCanvas.redraw_field_labels`
- redraw_field_points - `magneticalc.VisPyCanvas.VisPyCanvas.redraw_field_points`
- redraw_perspective_info - `magneticalc.VisPyCanvas.VisPyCanvas.redraw_perspective_info`
- redraw_start_time - `magneticalc.VisPyCanvas.VisPyCanvas.redraw_start_time`
- redraw_wire_points_selected - `magneticalc.VisPyCanvas.VisPyCanvas.redraw_wire_points_selected`
- redraw_wire_points_sliced - `magneticalc.VisPyCanvas.VisPyCanvas.redraw_wire_points_sliced`
- redraw_wire_segments - `magneticalc.VisPyCanvas.VisPyCanvas.redraw_wire_segments`
- rejecting - `magneticalc.QMessageBox2.QMessageBox2.rejecting`
- reload
  - `magneticalc.Constraint_Editor.Constraint_Editor.reload`
  - `magneticalc.Display_Widget.Display_Widget.reload`
  - `magneticalc.Field_Widget.Field_Widget.reload`
  - `magneticalc.GUI.GUI.reload`
  - `magneticalc.Menu.Menu.reload`
  - `magneticalc.Metric_Widget.Metric_Widget.reload`
  - `magneticalc.Parameters_Widget.Parameters_Widget.reload`
  - `magneticalc.Perspective_Widget.Perspective_Widget.reload`
  - `magneticalc.QCheckboxConfig.QCheckboxConfig.reload`
  - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.reload`
  - `magneticalc.Statusbar.Statusbar.reload`
  - `magneticalc.Wire_Widget.Wire_Widget.reload`
- remote_contents - `magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.remote_contents`
- remove_key - `magneticalc.Config.Config.remove_key`
- require_valid - `magneticalc.Validatable.require_valid`
- resolution - `magneticalc.SamplingVolume.SamplingVolume.resolution`
- resolution_combobox - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.resolution_combobox`
- resolution_units_label - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.resolution_units_label`
- ResolutionOptionsDict - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.ResolutionOptionsDict`
- rotational_symmetry_axis_combobox - `magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_axis_combobox`
- rotational_symmetry_count_spinbox - `magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_count_spinbox`
- rotational_symmetry_offset_spinbox - `magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_offset_spinbox`
- rotational_symmetry_radius_spinbox - `magneticalc.Wire_Widget.Wire_Widget.rotational_symmetry_radius_spinbox`
- RotationalSymmetryCountMax - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryCountMax`
- RotationalSymmetryCountMin - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryCountMin`
- RotationalSymmetryOffsetMax - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetMax`
- RotationalSymmetryOffsetMin - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetMin`
- RotationalSymmetryOffsetPrecision - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetPrecision`
- RotationalSymmetryOffsetStep - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryOffsetStep`
- RotationalSymmetryRadiusMax - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusMax`
- RotationalSymmetryRadiusMin - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusMin`
- RotationalSymmetryRadiusPrecision - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusPrecision`
- RotationalSymmetryRadiusStep - `magneticalc.Wire_Widget.Wire_Widget.RotationalSymmetryRadiusStep`
- rowCount - `magneticalc.QTableView2.TableModel.rowCount`
- rows - `magneticalc.Constraint_Editor.Constraint_Editor.rows`
- rows_count - `magneticalc.Constraint_Editor.Constraint_Editor.rows_count`
- run - `magneticalc.CalculationThread.CalculationThread.run`

## S

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- sampling_volume - `magneticalc.Model.Model.sampling_volume`
- sampling_volume_widget - `magneticalc.SidebarLeft.SidebarLeft.sampling_volume_widget`
- SamplingVolume
  - `magneticalc.SamplingVolume`
  - `magneticalc.SamplingVolume.SamplingVolume`
- SamplingVolume_Widget
  - `magneticalc.SamplingVolume_Widget`
  - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget`
- save_file - `magneticalc.Config.Config.save_file`
- save_image - `magneticalc.VisPyCanvas.VisPyCanvas.save_image`
- save_project_as - `magneticalc.File_Menu.File_Menu.save_project_as`
- ScaleFactorMax - `magneticalc.VisPyCanvas.VisPyCanvas.ScaleFactorMax`
- ScaleFactorMin - `magneticalc.VisPyCanvas.VisPyCanvas.ScaleFactorMin`
- select_cell - `magneticalc.QTableView2.QTableView2.select_cell`
- select_last_row - `magneticalc.QTableView2.QTableView2.select_last_row`
- self_inductance - `magneticalc.Parameters.Parameters.self_inductance`
- self_inductance_units_label - `magneticalc.Parameters_Widget.Parameters_Widget.self_inductance_units_label`
- self_inductance_value_label - `magneticalc.Parameters_Widget.Parameters_Widget.self_inductance_value_label`
- set
  - `magneticalc.Config_Group.Config_Collection.set`
  - `magneticalc.Field.Field.set`
  - `magneticalc.Metric.Metric.set`
  - `magneticalc.Parameters.Parameters.set`
  - `magneticalc.QtWidgets2.QLabel2.QLabel2.set`
  - `magneticalc.SamplingVolume.SamplingVolume.set`
  - `magneticalc.Wire.Wire.set`
- set_bool - `magneticalc.Config.Config.set_bool`
- set_bounds_nearest - `magneticalc.SamplingVolume.SamplingVolume.set_bounds_nearest`
- set_color - `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.set_color`
- set_data - `magneticalc.QTableView2.QTableView2.set_data`
- set_display_field_magnitude_labels - `magneticalc.Display_Widget.Display_Widget.set_display_field_magnitude_labels`
- set_field
  - `magneticalc.Field_Widget.Field_Widget.set_field`
  - `magneticalc.Model.Model.set_field`
- set_field_arrow_head_scale - `magneticalc.Display_Widget.Display_Widget.set_field_arrow_head_scale`
- set_field_arrow_line_scale - `magneticalc.Display_Widget.Display_Widget.set_field_arrow_line_scale`
- set_field_boost - `magneticalc.Display_Widget.Display_Widget.set_field_boost`
- set_field_label_resolution - `magneticalc.Display_Widget.Display_Widget.set_field_label_resolution`
- set_field_point_scale - `magneticalc.Display_Widget.Display_Widget.set_field_point_scale`
- set_float - `magneticalc.Config.Config.set_float`
- set_generic - `magneticalc.Config.Config.set_generic`
- set_get_bool - `magneticalc.Config.Config.set_get_bool`
- set_get_dict - `magneticalc.Config.Config.set_get_dict`
- set_get_float - `magneticalc.Config.Config.set_get_float`
- set_get_int - `magneticalc.Config.Config.set_get_int`
- set_get_point - `magneticalc.Config.Config.set_get_point`
- set_get_points - `magneticalc.Config.Config.set_get_points`
- set_get_str - `magneticalc.Config.Config.set_get_str`
- set_int - `magneticalc.Config.Config.set_int`
- set_metric
  - `magneticalc.Metric_Widget.Metric_Widget.set_metric`
  - `magneticalc.Model.Model.set_metric`
- set_padding_nearest - `magneticalc.SamplingVolume.SamplingVolume.set_padding_nearest`
- set_parameters - `magneticalc.Model.Model.set_parameters`
- set_perspective - `magneticalc.Perspective_Widget.Perspective_Widget.set_perspective`
- set_point - `magneticalc.Config.Config.set_point`
- set_points - `magneticalc.Config.Config.set_points`
- set_progress - `magneticalc.Statusbar.Statusbar.set_progress`
- set_progressbar_color - `magneticalc.Statusbar.Statusbar.set_progressbar_color`
- set_rotational_symmetry - `magneticalc.Wire_Widget.Wire_Widget.set_rotational_symmetry`
- set_sampling_volume
  - `magneticalc.Model.Model.set_sampling_volume`
  - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.set_sampling_volume`
- set_str - `magneticalc.Config.Config.set_str`
- set_stretch - `magneticalc.Wire_Widget.Wire_Widget.set_stretch`
- set_style - `magneticalc.QTableView2.QTableView2.set_style`
- set_text - `magneticalc.Statusbar.Statusbar.set_text`
- set_visible - `magneticalc.VisPyCanvas.VisPyCanvas.set_visible`
- set_wire
  - `magneticalc.Model.Model.set_wire`
  - `magneticalc.Wire_Widget.Wire_Widget.set_wire`
- setData - `magneticalc.QTableView2.TableModel.setData`
- setValue - `magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.setValue`
- show - `magneticalc.QtWidgets2.QDialog2.QDialog2.show`
- showEvent
  - `magneticalc.About_Dialog.About_Dialog.showEvent`
  - `magneticalc.Constraint_Editor.Constraint_Editor.showEvent`
  - `magneticalc.QtWidgets2.QDialog2.QDialog2.showEvent`
- sidebar_left - `magneticalc.GUI.GUI.sidebar_left`
- sidebar_right - `magneticalc.GUI.GUI.sidebar_right`
- SidebarLeft
  - `magneticalc.SidebarLeft`
  - `magneticalc.SidebarLeft.SidebarLeft`
- SidebarRight
  - `magneticalc.SidebarRight`
  - `magneticalc.SidebarRight.SidebarRight`
- signals_blocked - `magneticalc.VisPyCanvas.VisPyCanvas.signals_blocked`
- SingleCircularLoop_Offset - `magneticalc.Wire_Presets.Wire_Presets.SingleCircularLoop_Offset`
- SingleSquareLoop_Centered - `magneticalc.Wire_Presets.Wire_Presets.SingleSquareLoop_Centered`
- SingleSquareLoop_Offset - `magneticalc.Wire_Presets.Wire_Presets.SingleSquareLoop_Offset`
- sliced_total_label - `magneticalc.Wire_Widget.Wire_Widget.sliced_total_label`
- slicer_limit_spinbox - `magneticalc.Wire_Widget.Wire_Widget.slicer_limit_spinbox`
- SlicerLimitMax - `magneticalc.Wire_Widget.Wire_Widget.SlicerLimitMax`
- SlicerLimitMin - `magneticalc.Wire_Widget.Wire_Widget.SlicerLimitMin`
- SlicerLimitPrecision - `magneticalc.Wire_Widget.Wire_Widget.SlicerLimitPrecision`
- SlicerLimitStep - `magneticalc.Wire_Widget.Wire_Widget.SlicerLimitStep`
- SolenoidCircularLoops4 - `magneticalc.Wire_Presets.Wire_Presets.SolenoidCircularLoops4`
- SolenoidCircularLoops8 - `magneticalc.Wire_Presets.Wire_Presets.SolenoidCircularLoops8`
- splitter - `magneticalc.GUI.GUI.splitter`
- start - `magneticalc.Statusbar.Statusbar.start`
- Statusbar
  - `magneticalc.Statusbar`
  - `magneticalc.Statusbar.Statusbar`
- statusbar - `magneticalc.GUI.GUI.statusbar`
- str_to_point - `magneticalc.Format.Format.str_to_point`
- str_to_points - `magneticalc.Format.Format.str_to_points`
- StraightLine - `magneticalc.Wire_Presets.Wire_Presets.StraightLine`
- stretch_spinbox - `magneticalc.Wire_Widget.Wire_Widget.stretch_spinbox`
- StretchMax - `magneticalc.Wire_Widget.Wire_Widget.StretchMax`
- StretchMin - `magneticalc.Wire_Widget.Wire_Widget.StretchMin`
- StretchPrecision - `magneticalc.Wire_Widget.Wire_Widget.StretchPrecision`
- StretchStep - `magneticalc.Wire_Widget.Wire_Widget.StretchStep`
- String - `magneticalc.Version.Version.String`
- SuccessColor - `magneticalc.Theme.Theme.SuccessColor`
- super_perspective_changed - `magneticalc.VisPyCanvas.VisPyCanvas.super_perspective_changed`
- switch - `magneticalc.Project.Project.switch`
- synced - `magneticalc.Config.Config.synced`

## T

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- table
  - `magneticalc.Constraint_Editor.Constraint_Editor.table`
  - `magneticalc.Wire_Widget.Wire_Widget.table`
- table_total_label - `magneticalc.Wire_Widget.Wire_Widget.table_total_label`
- TableModel - `magneticalc.QTableView2.TableModel`
- text_browser
  - `magneticalc.About_Dialog.About_Dialog.text_browser`
  - `magneticalc.Constraint_Editor.Constraint_Editor.text_browser`
- Theme
  - `magneticalc.Theme`
  - `magneticalc.Theme.Theme`
- ToroidalLoop16 - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop16`
- ToroidalLoop32HiRes - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32HiRes`
- ToroidalLoop32HiResFlat - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32HiResFlat`
- ToroidalLoop32LoRes - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32LoRes`
- ToroidalLoop32LoResFlat - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop32LoResFlat`
- ToroidalLoop8 - `magneticalc.Wire_Presets.Wire_Presets.ToroidalLoop8`
- total_calculations - `magneticalc.Field.Field.total_calculations`
- total_calculations_label - `magneticalc.Field_Widget.Field_Widget.total_calculations_label`
- total_constraints_label - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.total_constraints_label`
- total_extent_label - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.total_extent_label`
- total_labels_label - `magneticalc.Display_Widget.Display_Widget.total_labels_label`
- total_points_label - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.total_points_label`
- total_skipped_calculations - `magneticalc.Field.Field.total_skipped_calculations`
- total_skipped_calculations_label - `magneticalc.Field_Widget.Field_Widget.total_skipped_calculations_label`
- transformed_total_label - `magneticalc.Wire_Widget.Wire_Widget.transformed_total_label`
- type - `magneticalc.Field.Field.type`
- types - `magneticalc.Config_Group.Config_Collection.types`

## U

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- UnitsLabelWidth
  - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.UnitsLabelWidth`
  - `magneticalc.Wire_Widget.Wire_Widget.UnitsLabelWidth`
- update
  - `magneticalc.Display_Widget.Display_Widget.update`
  - `magneticalc.Field_Widget.Field_Widget.update`
  - `magneticalc.File_Menu.File_Menu.update`
  - `magneticalc.Help_Menu.Help_Menu.update`
  - `magneticalc.Menu.Menu.update`
  - `magneticalc.Metric_Widget.Metric_Widget.update`
  - `magneticalc.Options_Menu.Options_Menu.update`
  - `magneticalc.Parameters_Widget.Parameters_Widget.update`
  - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.update`
  - `magneticalc.View_Menu.View_Menu.update`
  - `magneticalc.Wire_Menu.Wire_Menu.update`
  - `magneticalc.Wire_Widget.Wire_Widget.update`
- update_color_scheme - `magneticalc.VisPyCanvas.VisPyCanvas.update_color_scheme`
- update_controls
  - `magneticalc.Display_Widget.Display_Widget.update_controls`
  - `magneticalc.Field_Widget.Field_Widget.update_controls`
  - `magneticalc.Metric_Widget.Metric_Widget.update_controls`
  - `magneticalc.Parameters_Widget.Parameters_Widget.update_controls`
  - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.update_controls`
  - `magneticalc.Wire_Widget.Wire_Widget.update_controls`
- update_labels
  - `magneticalc.Display_Widget.Display_Widget.update_labels`
  - `magneticalc.Field_Widget.Field_Widget.update_labels`
  - `magneticalc.Metric_Widget.Metric_Widget.update_labels`
  - `magneticalc.Parameters_Widget.Parameters_Widget.update_labels`
  - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.update_labels`
  - `magneticalc.Wire_Widget.Wire_Widget.update_labels`
- update_padding - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.update_padding`
- update_rotational_symmetry - `magneticalc.Wire_Widget.Wire_Widget.update_rotational_symmetry`
- update_stretch - `magneticalc.Wire_Widget.Wire_Widget.update_stretch`
- update_table
  - `magneticalc.Constraint_Editor.Constraint_Editor.update_table`
  - `magneticalc.Wire_Widget.Wire_Widget.update_table`
- Usage_Dialog
  - `magneticalc.Usage_Dialog`
  - `magneticalc.Usage_Dialog.Usage_Dialog`
- user_accepted - `magneticalc.QtWidgets2.QDialog2.QDialog2.user_accepted`
- user_locale - `magneticalc.GUI.GUI.user_locale`

## V

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- valid
  - `magneticalc.Model.Model.valid`
  - `magneticalc.Validatable.Validatable.valid`
- valid.setter - `magneticalc.Validatable.Validatable.valid.setter`
- Validatable
  - `magneticalc.Validatable`
  - `magneticalc.Validatable.Validatable`
- validate
  - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.validate`
  - `magneticalc.Project.Project.validate`
- validator - `magneticalc.Validatable.validator`
- ValuePrecision
  - `magneticalc.Metric_Widget.Metric_Widget.ValuePrecision`
  - `magneticalc.Parameters_Widget.Parameters_Widget.ValuePrecision`
- vectors - `magneticalc.Field.Field.vectors`
- vectors_count - `magneticalc.Field.Field.vectors_count`
- Version
  - `magneticalc.Version`
  - `magneticalc.Version.Version`
- VerticalSpacing
  - `magneticalc.QtWidgets2.QHLine.QHLine.VerticalSpacing`
  - `magneticalc.SidebarLeft.SidebarLeft.VerticalSpacing`
  - `magneticalc.SidebarRight.SidebarRight.VerticalSpacing`
- view_main - `magneticalc.VisPyCanvas.VisPyCanvas.view_main`
- View_Menu
  - `magneticalc.View_Menu`
  - `magneticalc.View_Menu.View_Menu`
- view_menu - `magneticalc.Menu.Menu.view_menu`
- view_text - `magneticalc.VisPyCanvas.VisPyCanvas.view_text`
- vispy_canvas - `magneticalc.GUI.GUI.vispy_canvas`
- VisPyCanvas
  - `magneticalc.VisPyCanvas`
  - `magneticalc.VisPyCanvas.VisPyCanvas`
- visual_coordinate_system - `magneticalc.VisPyCanvas.VisPyCanvas.visual_coordinate_system`
- visual_field_arrow_heads - `magneticalc.VisPyCanvas.VisPyCanvas.visual_field_arrow_heads`
- visual_field_arrow_lines - `magneticalc.VisPyCanvas.VisPyCanvas.visual_field_arrow_lines`
- visual_field_labels - `magneticalc.VisPyCanvas.VisPyCanvas.visual_field_labels`
- visual_field_points - `magneticalc.VisPyCanvas.VisPyCanvas.visual_field_points`
- visual_perspective_info - `magneticalc.VisPyCanvas.VisPyCanvas.visual_perspective_info`
- visual_startup_info - `magneticalc.VisPyCanvas.VisPyCanvas.visual_startup_info`
- visual_wire_points_selected - `magneticalc.VisPyCanvas.VisPyCanvas.visual_wire_points_selected`
- visual_wire_points_sliced - `magneticalc.VisPyCanvas.VisPyCanvas.visual_wire_points_sliced`
- visual_wire_segments - `magneticalc.VisPyCanvas.VisPyCanvas.visual_wire_segments`

## W

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- White - `magneticalc.VisPyCanvas.VisPyCanvas.White`
- Wire
  - `magneticalc.Wire`
  - `magneticalc.Wire.Wire`
- wire - `magneticalc.Model.Model.wire`
- wire_export - `magneticalc.Wire_Menu.Wire_Menu.wire_export`
- wire_import - `magneticalc.Wire_Menu.Wire_Menu.wire_import`
- wire_length_units_label - `magneticalc.Parameters_Widget.Parameters_Widget.wire_length_units_label`
- wire_length_value_label - `magneticalc.Parameters_Widget.Parameters_Widget.wire_length_value_label`
- Wire_Menu
  - `magneticalc.Wire_Menu`
  - `magneticalc.Wire_Menu.Wire_Menu`
- wire_menu - `magneticalc.Menu.Menu.wire_menu`
- Wire_Presets
  - `magneticalc.Wire_Presets`
  - `magneticalc.Wire_Presets.Wire_Presets`
- Wire_Widget
  - `magneticalc.Wire_Widget`
  - `magneticalc.Wire_Widget.Wire_Widget`
- wire_widget - `magneticalc.SidebarLeft.SidebarLeft.wire_widget`
- WirePointSelectedColor - `magneticalc.VisPyCanvas.VisPyCanvas.WirePointSelectedColor`
- WirePointSelectedSize - `magneticalc.VisPyCanvas.VisPyCanvas.WirePointSelectedSize`
- WirePointSize - `magneticalc.VisPyCanvas.VisPyCanvas.WirePointSize`
- worker
  - `magneticalc.Backend_CUDA.Backend_CUDA.worker`
  - `magneticalc.Backend_JIT.Backend_JIT.worker`

## _

A - B - C - D - E - F - G - H - I - K - L - M - N - O - P - Q - R - S - T - U - V - W - _

- __call__ - `magneticalc.ConditionalDecorator.ConditionalDecorator.__call__`
- __delitem__ - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__delitem__`
- __enter__ - `magneticalc.ModelAccess.ModelAccess.__enter__`
- __exit__ - `magneticalc.ModelAccess.ModelAccess.__exit__`
- __getitem__ - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__getitem__`
- __init__
  - `magneticalc.About_Dialog.About_Dialog.__init__`
  - `magneticalc.Assert_Dialog.Assert_Dialog.__init__`
  - `magneticalc.Backend_CUDA.Backend_CUDA.__init__`
  - `magneticalc.Backend_JIT.Backend_JIT.__init__`
  - `magneticalc.CalculationThread.CalculationThread.__init__`
  - `magneticalc.CheckForUpdates_Dialog.CheckForUpdates_Dialog.__init__`
  - `magneticalc.ConditionalDecorator.ConditionalDecorator.__init__`
  - `magneticalc.Config.Config.__init__`
  - `magneticalc.Config_Group.Config_Collection.__init__`
  - `magneticalc.Constraint.Constraint.__init__`
  - `magneticalc.Constraint_Editor.Constraint_Editor.__init__`
  - `magneticalc.Debug.Debug.__init__`
  - `magneticalc.Display_Widget.Display_Widget.__init__`
  - `magneticalc.ExportContainer_Dialog.ExportContainer_Dialog.__init__`
  - `magneticalc.Field.Field.__init__`
  - `magneticalc.Field_Widget.Field_Widget.__init__`
  - `magneticalc.File_Menu.File_Menu.__init__`
  - `magneticalc.GUI.GUI.__init__`
  - `magneticalc.Help_Menu.Help_Menu.__init__`
  - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__init__`
  - `magneticalc.Menu.Menu.__init__`
  - `magneticalc.Metric.Metric.__init__`
  - `magneticalc.Metric_Widget.Metric_Widget.__init__`
  - `magneticalc.Model.Model.__init__`
  - `magneticalc.ModelAccess.ModelAccess.__init__`
  - `magneticalc.Options_Menu.Options_Menu.__init__`
  - `magneticalc.OverridePadding_Dialog.OverridePadding_Dialog.__init__`
  - `magneticalc.Parameters.Parameters.__init__`
  - `magneticalc.Parameters_Widget.Parameters_Widget.__init__`
  - `magneticalc.Perspective_Widget.Perspective_Widget.__init__`
  - `magneticalc.Project.Project.__init__`
  - `magneticalc.QCheckboxConfig.QCheckboxConfig.__init__`
  - `magneticalc.QMessageBox2.QMessageBox2.__init__`
  - `magneticalc.QTableView2.QTableView2.__init__`
  - `magneticalc.QTableView2.TableModel.__init__`
  - `magneticalc.QtWidgets2.QButtons.QButtons.__init__`
  - `magneticalc.QtWidgets2.QDialog2.QDialog2.__init__`
  - `magneticalc.QtWidgets2.QDoubleSpinBox2.QDoubleSpinBox2.__init__`
  - `magneticalc.QtWidgets2.QGroupBox2.QGroupBox2.__init__`
  - `magneticalc.QtWidgets2.QHBoxLayout2.QHBoxLayout2.__init__`
  - `magneticalc.QtWidgets2.QHLine.QHLine.__init__`
  - `magneticalc.QtWidgets2.QIconLabel.QIconLabel.__init__`
  - `magneticalc.QtWidgets2.QLabel2.QLabel2.__init__`
  - `magneticalc.QtWidgets2.QLayouted.QLayouted.__init__`
  - `magneticalc.QtWidgets2.QPushButton2.QPushButton2.__init__`
  - `magneticalc.QtWidgets2.QSaveAction.QSaveAction.__init__`
  - `magneticalc.QtWidgets2.QSliderFloat.QSliderFloat.__init__`
  - `magneticalc.QtWidgets2.QSpinBox2.QSpinBox2.__init__`
  - `magneticalc.QtWidgets2.QTextBrowser2.QTextBrowser2.__init__`
  - `magneticalc.SamplingVolume.SamplingVolume.__init__`
  - `magneticalc.SamplingVolume_Widget.SamplingVolume_Widget.__init__`
  - `magneticalc.SidebarLeft.SidebarLeft.__init__`
  - `magneticalc.SidebarRight.SidebarRight.__init__`
  - `magneticalc.Statusbar.Statusbar.__init__`
  - `magneticalc.Usage_Dialog.Usage_Dialog.__init__`
  - `magneticalc.Validatable.Validatable.__init__`
  - `magneticalc.View_Menu.View_Menu.__init__`
  - `magneticalc.VisPyCanvas.VisPyCanvas.__init__`
  - `magneticalc.Wire.Wire.__init__`
  - `magneticalc.Wire_Menu.Wire_Menu.__init__`
  - `magneticalc.Wire_Widget.Wire_Widget.__init__`
- __iter__ - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__iter__`
- __len__ - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__len__`
- __main__ - `magneticalc.__main__`
- __PYPI_SIMPLE__URL__ - `magneticalc.Version.__PYPI_SIMPLE__URL__`
- __setitem__ - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data.__setitem__`
- __URL__ - `magneticalc.Version.__URL__`
- __VERSION__ - `magneticalc.Version.__VERSION__`
- _allow_delete - `magneticalc.QTableView2.QTableView2._allow_delete`
- _auto_calculation_changed - `magneticalc.Statusbar.Statusbar._auto_calculation_changed`
- _auto_calculation_checkbox - `magneticalc.Statusbar.Statusbar._auto_calculation_checkbox`
- _bounds_max - `magneticalc.SamplingVolume.SamplingVolume._bounds_max`
- _bounds_min - `magneticalc.SamplingVolume.SamplingVolume._bounds_min`
- _cancel_button - `magneticalc.Statusbar.Statusbar._cancel_button`
- _canceled - `magneticalc.Statusbar.Statusbar._canceled`
- _changed - `magneticalc.Constraint_Editor.Constraint_Editor._changed`
- _col_is_widget - `magneticalc.QTableView2.TableModel._col_is_widget`
- _col_keys
  - `magneticalc.QTableView2.QTableView2._col_keys`
  - `magneticalc.QTableView2.TableModel._col_keys`
- _col_options - `magneticalc.QTableView2.QTableView2._col_options`
- _col_types - `magneticalc.QTableView2.QTableView2._col_types`
- _colors - `magneticalc.Metric.Metric._colors`
- _comparison_type - `magneticalc.Constraint.Constraint._comparison_type`
- _constraint_collection - `magneticalc.Constraint_Editor.Constraint_Editor._constraint_collection`
- _constraints - `magneticalc.SamplingVolume.SamplingVolume._constraints`
- _cores_combobox - `magneticalc.Statusbar.Statusbar._cores_combobox`
- _current_elements
  - `magneticalc.Backend_CUDA.Backend_CUDA._current_elements`
  - `magneticalc.Backend_JIT.Backend_JIT._current_elements`
- _data - `magneticalc.QTableView2.TableModel._data`
- _dc
  - `magneticalc.Backend_CUDA.Backend_CUDA._dc`
  - `magneticalc.Backend_JIT.Backend_JIT._dc`
- _dialog - `magneticalc.Assert_Dialog.Assert_Dialog._dialog`
- _dict_to_hdf5_group - `magneticalc.API.API._dict_to_hdf5_group`
- _dimension - `magneticalc.SamplingVolume.SamplingVolume._dimension`
- _distance_limit
  - `magneticalc.Backend_CUDA.Backend_CUDA._distance_limit`
  - `magneticalc.Backend_JIT.Backend_JIT._distance_limit`
  - `magneticalc.Field.Field._distance_limit`
- _divergence_worker - `magneticalc.Metric.Metric._divergence_worker`
- _elements - `magneticalc.Wire.Wire._elements`
- _energy - `magneticalc.Parameters.Parameters._energy`
- _field_cache - `magneticalc.Model.Model._field_cache`
- _field_type
  - `magneticalc.Backend_CUDA.Backend_CUDA._field_type`
  - `magneticalc.Backend_JIT.Backend_JIT._field_type`
- _field_type_select - `magneticalc.Model.Model._field_type_select`
- _field_valid - `magneticalc.CalculationThread.CalculationThread._field_valid`
- _get_fields - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data._get_fields`
- _get_magnetic_dipole_moment - `magneticalc.Parameters.Parameters._get_magnetic_dipole_moment`
- _get_magnetic_dipole_moment_worker - `magneticalc.Parameters.Parameters._get_magnetic_dipole_moment_worker`
- _get_squared_field - `magneticalc.Parameters.Parameters._get_squared_field`
- _get_squared_field_worker - `magneticalc.Parameters.Parameters._get_squared_field_worker`
- _get_suffix - `magneticalc.Config_Group.Config_Collection._get_suffix`
- _hdf5_group_to_dict - `magneticalc.API.API._hdf5_group_to_dict`
- _i_to_xyz - `magneticalc.SamplingVolume.SamplingVolume._i_to_xyz`
- _keytransform - `magneticalc.MagnetiCalc_Data.MagnetiCalc_Data._keytransform`
- _label - `magneticalc.Statusbar.Statusbar._label`
- _label_resolution - `magneticalc.SamplingVolume.SamplingVolume._label_resolution`
- _labeled_indices - `magneticalc.SamplingVolume.SamplingVolume._labeled_indices`
- _layout - `magneticalc.QtWidgets2.QLayouted.QLayouted._layout`
- _length - `magneticalc.Wire.Wire._length`
- _length_scale
  - `magneticalc.Backend_CUDA.Backend_CUDA._length_scale`
  - `magneticalc.Backend_JIT.Backend_JIT._length_scale`
  - `magneticalc.Field.Field._length_scale`
- _limits - `magneticalc.Metric.Metric._limits`
- _magnetic_dipole_moment - `magneticalc.Parameters.Parameters._magnetic_dipole_moment`
- _max - `magneticalc.Constraint.Constraint._max`
- _metric_valid - `magneticalc.CalculationThread.CalculationThread._metric_valid`
- _min - `magneticalc.Constraint.Constraint._min`
- _neighbor_indices - `magneticalc.SamplingVolume.SamplingVolume._neighbor_indices`
- _norm_type - `magneticalc.Constraint.Constraint._norm_type`
- _norm_worker - `magneticalc.Metric.Metric._norm_worker`
- _normalize_worker - `magneticalc.Metric.Metric._normalize_worker`
- _on_cell_edited - `magneticalc.QTableView2.QTableView2._on_cell_edited`
- _on_finished - `magneticalc.CalculationThread.CalculationThread._on_finished`
- _on_row_deleted - `magneticalc.QTableView2.QTableView2._on_row_deleted`
- _on_selection_changed - `magneticalc.QTableView2.QTableView2._on_selection_changed`
- _parameters_valid - `magneticalc.CalculationThread.CalculationThread._parameters_valid`
- _parser - `magneticalc.Config.Config._parser`
- _permeabilities - `magneticalc.SamplingVolume.SamplingVolume._permeabilities`
- _points - `magneticalc.SamplingVolume.SamplingVolume._points`
- _points_sliced - `magneticalc.Wire.Wire._points_sliced`
- _progress_callback
  - `magneticalc.Backend_CUDA.Backend_CUDA._progress_callback`
  - `magneticalc.Backend_JIT.Backend_JIT._progress_callback`
- _progress_update - `magneticalc.CalculationThread.CalculationThread._progress_update`
- _progressbar - `magneticalc.Statusbar.Statusbar._progressbar`
- _recalculate - `magneticalc.ModelAccess.ModelAccess._recalculate`
- _row_count_minimum - `magneticalc.QTableView2.QTableView2._row_count_minimum`
- _row_keys - `magneticalc.QTableView2.TableModel._row_keys`
- _row_prefix - `magneticalc.QTableView2.QTableView2._row_prefix`
- _sampling_volume_permeabilities
  - `magneticalc.Backend_CUDA.Backend_CUDA._sampling_volume_permeabilities`
  - `magneticalc.Backend_JIT.Backend_JIT._sampling_volume_permeabilities`
- _sampling_volume_points
  - `magneticalc.Backend_CUDA.Backend_CUDA._sampling_volume_points`
  - `magneticalc.Backend_JIT.Backend_JIT._sampling_volume_points`
- _sampling_volume_valid - `magneticalc.CalculationThread.CalculationThread._sampling_volume_valid`
- _self_inductance - `magneticalc.Parameters.Parameters._self_inductance`
- _slicer_limit - `magneticalc.Wire.Wire._slicer_limit`
- _start_button - `magneticalc.Statusbar.Statusbar._start_button`
- _step - `magneticalc.QtWidgets2.QSliderFloat.QSliderFloat._step`
- _total_calculations - `magneticalc.Field.Field._total_calculations`
- _total_skipped_calculations - `magneticalc.Field.Field._total_skipped_calculations`
- _transform_rotational_symmetry - `magneticalc.Wire.Wire._transform_rotational_symmetry`
- _transform_stretch - `magneticalc.Wire.Wire._transform_stretch`
- _valid
  - `magneticalc.Statusbar.Statusbar._valid`
  - `magneticalc.Validatable.Validatable._valid`
- _vectors - `magneticalc.Field.Field._vectors`
- _wire_valid - `magneticalc.CalculationThread.CalculationThread._wire_valid`
- _xyz_to_i - `magneticalc.SamplingVolume.SamplingVolume._xyz_to_i`